==> Legcord-1.1.5.tar.gz: Legcord-1.1.5/src/shelter/settings/pages/ThemesPage.tsx <==
import { For, createSignal } from "solid-js";
import type { ThemeManifest } from "../../../@types/themeManifest.js";
import { ThemesCard } from "../components/ThemesCard.jsx";
import { refreshThemes } from "../settings.js";
import classes from "./ThemesPages.module.css";

const {
    ui: { Button, Header, HeaderTags, ButtonSizes, Divider, TextBox, showToast },
    plugin: { store },
} = shelter;

export function ThemesPage() {
    const [downloadUrl, setDownloadUrl] = createSignal("");
    refreshThemes();

    function installTheme() {
        window.legcord.themes.install(downloadUrl());
        setDownloadUrl("");
        setTimeout(() => {
            refreshThemes();
        }, 1000);
        showToast({
            title: "Success!",
            content: "BD theme successfully installed!",
            duration: 3000,
        });
    }

    return (
        <>
            <Header tag={HeaderTags.H1}>Themes</Header>
            <Divider mt mb />
            <div class={classes.buttonBox}>
                <Button size={ButtonSizes.LARGE} onClick={window.legcord.themes.openQuickCss}>
                    Open Quick CSS file
                </Button>
                <Button size={ButtonSizes.LARGE} onClick={window.legcord.themes.openImportPicker}>
                    Import from file
                </Button>
                <Button size={ButtonSizes.LARGE} onClick={window.legcord.settings.openThemesFolder}>
                    Open themes folder
                </Button>
            </div>
            <div class={classes.addBox}>
                <TextBox
                    value={downloadUrl()}
                    onInput={setDownloadUrl}
                    placeholder="https://raw.githubusercontent.com/... [.theme.css]"
                />
                <Button size={ButtonSizes.MEDIUM} onClick={installTheme}>
                    Import
                </Button>
            </div>
            <For each={store.themes}>{(theme: ThemeManifest) => <ThemesCard theme={theme} />}</For>
        </>
    );
}

==> Legcord-1.2.1.tar.gz: Legcord-1.2.1/src/shelter/settings/pages/ThemesPage.tsx <==
import { For, createSignal } from "solid-js";
import type { ThemeManifest } from "../../../@types/themeManifest.js";
import { ThemesCard } from "../components/ThemesCard.jsx";
import { refreshThemes } from "../settings.js";
import classes from "./ThemesPages.module.css";

const {
    ui: { Button, Header, HeaderTags, ButtonSizes, Divider, TextBox, showToast },
    plugin: { store },
} = shelter;

export function ThemesPage() {
    const [downloadUrl, setDownloadUrl] = createSignal("");
    refreshThemes();

    function installTheme() {
        window.legcord.themes.install(downloadUrl());
        setDownloadUrl("");
        setTimeout(() => {
            refreshThemes();
        }, 1000);
        showToast({
            title: store.i18n["themes-success"],
            content: store.i18n["themes-bdInstalled"],
            duration: 3000,
        });
    }

    const t = store.i18n;
    return (
        <>
            <Header tag={HeaderTags.H1}>Themes</Header>
            <Divider mt mb />
            <div class={classes.buttonBox}>
                <Button size={ButtonSizes.LARGE} onClick={window.legcord.themes.openQuickCss}>
                    {t["themes-openQuickCss"]}
                </Button>
                <Button size={ButtonSizes.LARGE} onClick={window.legcord.themes.openImportPicker}>
                    {t["themes-importFromFile"]}
                </Button>
                <Button size={ButtonSizes.LARGE} onClick={window.legcord.settings.openThemesFolder}>
                    {t["themes-openThemesFolder"]}
                </Button>
            </div>
            <div class={classes.addBox}>
                <TextBox
                    value={downloadUrl()}
                    onInput={setDownloadUrl}
                    placeholder={t["themes-importUrlPlaceholder"]}
                />
                <Button size={ButtonSizes.MEDIUM} onClick={installTheme}>
                    {t["themes-import"]}
                </Button>
            </div>
            <For each={store.themes}>{(theme: ThemeManifest) => <ThemesCard theme={theme} />}</For>
        </>
    );
}
